@@ -25,11 +25,13 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 		self.show_all()
 
 	def click(self, button):
-		if self.getDriverStatus() != self.status:
+		realStatus = self.getDriverStatus()
+		if realStatus != self.status:
 			if self.status:
 				self.Notifications.notify("Stock drivers are already in use")
 			else:
 				self.Notifications.notify("Bleeding Edge drivers are already in use")
+			self.status = realStatus
 		else:
 			folder = self.Config.getFolder()
 			if self.Config.checkFolder(folder):
@@ -39,7 +41,7 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 					self.loadDrivers(folder, True)
 			else:
 				SetupDialog(self)
-			self.updateButton()
+		self.updateButton()
 
 	def loadDrivers(self, folder, driver):
 		if driver:
